@@ -529,38 +529,6 @@ class Microservices(BaseClass, ABC):
                     msg.get('data', {})
                 ))
 
-        """ try:
-            TIME = msg['metadata']['time']
-            DATE = None
-            IS_Z = TIME.find('Z') > -1
-            currDate = datetime.datetime.utcnow()
-
-            if IS_Z:
-                include_mil = re.search(
-                    r"\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d{1,}z",
-                    TIME
-                )
-                if include_mil:
-                    DATE = datetime.datetime.strptime(
-                        TIME,
-                        '%Y-%m-%dT%H:%M:%S.%fZ'
-                    )
-                else:
-                    DATE = datetime.datetime.strptime(
-                        TIME,
-                        '%Y-%m-%dT%H:%M:%SZ'
-                    )
-
-                elapsedTime = currDate - DATE
-                diff = divmod(elapsedTime.total_seconds(), 60)[0]
-                if diff >= 5:
-                    # print('EXIT TIME : ', msg['metadata']['time'], ' ', diff)
-                    pass
-
-        except Exception as e:
-            self.logs.warn(
-                'Error al momento de procesar el tiempo del mensaje', e) """
-
         # Procesar el mensaje
         try:
             mth = self.__getMethod(msg.get('metadata'))
@@ -594,8 +562,7 @@ class Microservices(BaseClass, ABC):
             rootSpan = self.___Tracer.extract(Format.TEXT_MAP, rootSpan)
 
         if mth is None:
-            span = self.___Tracer.start_span(
-                operation_name='No identificado')
+            span = self.___Tracer.start_span(operation_name='No identificado')
         else:
             span = self.___Tracer.start_span(operation_name=getattr(
                 mth, '__FUNC_NAME__'), references=child_of(rootSpan))
